/*  Copyright (C) 2009, Jean-Baptiste LANGLOIS

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
    as published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.*/

using System;
using System.Collections.Generic;
using System.Text;

namespace System.Json
{
    /// <summary>
    /// Type of the node of the data
    /// </summary>
    /// <seealso cref="JsonData"/>
    public enum JsonType
    {
        /// <summary>
        /// End of the array
        /// </summary>
        /// <remarks>Unuseful</remarks>
        ArrayClose,
        /// <summary>
        /// The node is an array
        /// </summary>
        Array,
        /// <summary>
        /// The current position is a colon (':')
        /// </summary>
        /// <remarks>Unuseful</remarks>
        Colon,
        /// <summary>
        /// The current position is a comma (',')
        /// </summary>
        /// <remarks>Unuseful</remarks>
        Comma,
        /// <summary>
        /// The node is a boolean : false
        /// </summary>
        False,
        /// <summary>
        /// End of object
        /// </summary>
        /// <remarks>Unuseful</remarks>
        ObjectClose,
        /// <summary>
        /// The node is an object
        /// </summary>
        /// <seealso cref="JsonData"/>
        Object,
        /// <summary>
        /// The node is empty
        /// </summary>
        None,
        /// <summary>
        /// The node is null
        /// </summary>
        Null,
        /// <summary>
        /// The node is a number (Double or Integer)
        /// </summary>
        Number,
        /// <summary>
        /// The node is character string
        /// </summary>
        String,
        /// <summary>
        /// The node is a boolean : true
        /// </summary>
        True
    };
}